#####################################################################################
#
# This package is intended to create all users/groups that are required for InterWorx
# and building supporting packages.
#
# These are being added as encountered while rebuilding rpms, so it may not yet
# represent the full list of users.
#
# Known to account for:
#  - iworx-db-55
#  - vpopmail
#  - qmail
#  - interworx
#
#####################################################################################

%define         pversion 1.0
%define         bversion 8
%define 	    rpmrelease iworx
%define         release %{bversion}.noarch.%{rpmrelease}

#####################################################################################

# From Vpopmail
%define 	vdir /home/vpopmail
%define 	vuid 108
%define 	vgid 104
%define 	qdir /var/qmail

#####################################################################################

##
# qmail user mapping
##

%define 	qmaildir /var/qmail

%define		alias_usr  alias
%define		alias_uid  101
%define		alias_grp  nofiles
%define		alias_dir  %{qmaildir}/alias
%define		alias_add  %( %{__grep} -q alias /etc/passwd ; echo $? )

%define		qmaild_usr qmaild
%define		qmaild_uid 102
%define		qmaild_grp nofiles
%define		qmaild_dir %{qmaildir}
%define		qmaild_add %( %{__grep} -q qmaild /etc/passwd ; echo $? )

%define		qmaill_usr qmaill
%define		qmaill_uid 103
%define		qmaill_grp nofiles
%define		qmaill_dir %{qmaildir}
%define		qmaill_add %( %{__grep} -q qmaill /etc/passwd ; echo $? )

%define		qmailp_usr qmailp
%define		qmailp_uid 104
%define		qmailp_grp nofiles
%define		qmailp_dir %{qmaildir}
%define		qmailp_add %( %{__grep} -q qmailp /etc/passwd ; echo $? )

%define		qmailq_usr qmailq
%define		qmailq_uid 105
%define		qmailq_grp qmail
%define 	qmailq_dir %{qmaildir}
%define		qmailq_add %( %{__grep} -q qmailq /etc/passwd ; echo $? )

%define		qmailr_usr qmailr
%define 	qmailr_uid 106
%define		qmailr_grp qmail
%define		qmailr_dir %{qmaildir}
%define		qmailr_add %( %{__grep} -q qmailr /etc/passwd ; echo $? )

%define		qmails_usr qmails
%define		qmails_uid 107
%define		qmails_grp qmail
%define		qmails_dir %{qmaildir}
%define		qmails_add %( %{__grep} -q qmails /etc/passwd ; echo $? )

##
# qmail group mapping
##

%define		nofiles_grp nofiles
%define		nofiles_gid 102
%define		nofiles_add %( %{__grep} -q nofiles /etc/group ; echo $? )

%define		qmail_grp   qmail
%define		qmail_gid   103
%define		qmail_add   %( %{__grep} -q qmail /etc/group ; echo $? )

#####################################################################################

Summary:      InterWorx Base Users
Name:         interworx-unix-users
Version:      %{pversion}
Release:      %{release}
License:      Commercial
Group:	      Development/Languages
Distribution: InterWorx-HAL
Vendor:       INTERWORX L.L.C
Packager:     Tim College <tcollege@interworx.com>

%description
Helper package to ensure InterWorx related users are in place with the
correct groups for building and installing InterWorx packages.

%pre

# make the iworx group (if needed)
/bin/grep "^%{_iworx_group}:" /etc/group > /dev/null || groupadd --system --gid %{_iworx_gid} %{_iworx_group}

# make the vchkpw group (if needed)
/bin/grep "vchkpw:" /etc/group > /dev/null || groupadd --system --gid %{vgid} vchkpw

# make the iworx  user (if needed)
/bin/grep "^%{_iworx_user}:" /etc/passwd > /dev/null || /usr/sbin/useradd \
    --uid %{_iworx_uid} --gid %{_iworx_group} --groups vchkpw --home-dir %{_iworx_dir} \
    --shell /bin/bash --comment %{name} --system --create-home %{_iworx_user}

# make the vpopmail user if needed
/bin/grep "^vpopmail:" /etc/passwd >/dev/null || /usr/sbin/useradd \
    --uid %{vuid} --gid vchkpw --home-dir %{vdir} --shell /bin/true --comment %{name} --system \
    --create-home --skel /dev/null vpopmail

#####################################################################################
# iworx-backup
# make the iworx-backup group (if needed)
/bin/grep "^%{_iworx_backup_group}:" /etc/group >/dev/null || groupadd -r %{_iworx_backup_group}

# make the iworx-backup user (if needed)
/bin/grep "^%{_iworx_backup_user}:" /etc/passwd >/dev/null || /usr/sbin/useradd \
        -g %{_iworx_backup_group} -d / \
        -s /sbin/nologin -c %{name} -r %{_iworx_backup_user}

# Add iworx-backup to the iworx group.
/usr/sbin/usermod -a -G %{_iworx_group} %{_iworx_backup_user}

#####################################################################################
# Qmail users/groups
if [ -z "`/usr/bin/id -g nofiles 2>/dev/null`" ]; then
	/usr/sbin/groupadd -g %{nofiles_gid} -r nofiles > /dev/null 2>&1 || :
fi
if [ -z "`/usr/bin/id -g qmail 2>/dev/null`" ]; then
	/usr/sbin/groupadd -g %{qmail_gid} -r qmail > /dev/null 2>&1 || :
fi
if [ -z "`/usr/bin/id -u alias 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{alias_uid} -r -M -d %{qmaildir}/alias -s /sbin/nologin -c "qmail alias" -g qmail alias  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmaild 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmaild_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail daemon" -g qmail qmaild  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmaill 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmaill_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail logger" -g qmail qmaill  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmailp 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmailp_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail passwd" -g qmail qmailp  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmailq 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmailq_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail queue" -g qmail qmailq  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmailr 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmailr_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail remote" -g qmail qmailr  2>&1 || :
fi
if [ -z "`/usr/bin/id -u qmails 2>/dev/null`" ]; then
	/usr/sbin/useradd -u %{qmails_uid} -r -M -d %{qmaildir} -s /sbin/nologin -c "qmail send" -g qmail qmails  2>&1 || :
fi

#####################################################################################

# Simscan user
# see if we already have the user(s) on the system
# since if we don't we need to kill them after the
# build.

function add_simscan_user() {
        usr=$1; shift
        uid=$1; shift
        useradd \
                -s /bin/false \
                -r            \
                -u $uid       \
                -M            \
                $usr
        return 0
}

[ %{simscan_add} -gt 0 ] &&
        add_simscan_user %{simscan_user} %{simscan_uid}


%files

%changelog

* Thu Oct 07 2021 Tim College <tcollege@interworx.com>
- Initial package version
